@@ -2,7 +2,7 @@ package Test::Search::Typesense;
 
 use Moo;
 use Test::Most ();
-use Search::Typesense;
+use Test::Search::Typesense::Cached;
 use Search::Typesense::Types qw(
   InstanceOf
 );
@@ -14,9 +14,10 @@ has typesense => (
 );
 
 sub _build_typesense {
-    my $self      = shift;
-    my $typesense = eval {
-        Search::Typesense->new(
+    my $self = shift;
+    my $typesense;
+    eval {
+        $typesense = Test::Search::Typesense::Cached->new(
             use_https => 0,
             host      => 'localhost',
             port      => 7777,
@@ -28,18 +29,21 @@ sub _build_typesense {
         return $typesense;
     }
 
+    my $reason = $@;
     Test::Most::explain(<<"END");
 If they don't have Typesense running, we skip the tests and give them the
 information they need to get the tests running. However, if they're running a
 bizarrely old version of Typesense (< 0.8.0), we don't guarantee support and
 we bail out.
+
+Error reason: $reason
 END
     Test::More::plan( skip_all =>
-"Typesense does not appear to be running. See the CONTRIBUTING.md document with this distribution."
+          "Typesense does not appear to be running. See the CONTRIBUTING.md document with this distribution."
     );
     unless ( $typesense->typesense_version ) {
         Test::More::diag(
-"https://github.com/typesense/typesense-api-spec/commit/778ad3e0d2bdf23e6ccc1b23113ae6f48ec345fb"
+            "https://github.com/typesense/typesense-api-spec/commit/778ad3e0d2bdf23e6ccc1b23113ae6f48ec345fb"
         );
         Test::More::BAIL_OUT(
             "You're using a version of Typesense earlier than 0.8.0.");
